/*---------------------------------------------------------------------------
 * nsc_init.c
 *
 * This file contains the driver initialization code.  It makes use of the 
 * Durango graphics software support package from National.
 *
 * It is ported from the Cyrix driver developed by Annius Groenink.
 *
 * Copyright (C) 1999-2000 National Semiconductor Corporation. All Rights Reserved.
 *
 * Permission is granted, royalty-free, to any person obtaining a copy of this 
 * software and associated documentation files (the "Software"), to deal in the 
 * Software without restriction, including without limitation the rights to use, 
 * copy, modify, merge, publish, distribute, sublicense, and/or sell copies of 
 * the Software, and to permit persons to whom the Software is furnished to do so, 
 * subject to the following conditions:
 *
 *   The above copyright notice and this permission notice shall be included in
 *   all copies or substantial portions of the Software in whatever form or media.
 *
 *   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, 
 *   EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES 
 *   OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
 *   IN NO EVENT SHALL NATIONAL SEMICONDUCTOR BE LIABLE FOR ANY CLAIM, 
 *   DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, 
 *   TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
 *   SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 *
 * Except as contained in this permission notice, the name of National Semiconductor 
 * shall not be used in advertising or otherwise to promote the sale, use or other 
 * dealings in this Software without prior written authorization from National Semiconductor.
 *
 *---------------------------------------------------------------------------
 */

/* Xfree86 header files */

#include "xf86.h"
#include "xf86Priv.h"
#include "xf86_OSlib.h"
#include "xf86_HWlib.h"
#include "vga.h"
#include "vga256.h"
#define XCONFIG_FLAGS_ONLY
#include "xf86_Config.h"

/* National Semicondictor header files. */

#include "gfx_rtns.h"

extern vgaHWCursorRec vgaHWCursor;

extern Bool GeodeCursorInit();
extern void GeodeRestoreCursor();
extern void GeodeWarpCursor();
extern void GeodeQueryBestSize();

/* MEMORY ORGANIZATION */

unsigned long geodeCursorOffset;
unsigned long geodeOffscreenOffset;
unsigned long geodeOffscreenSize;

/* VGA STRUCUTE FOR INIT/SAVE/RESTORE */

typedef struct {
	vgaHWRec std;					/* IBM VGA */
	gfx_vga_struct durangovga;		/* Extended VGA */
} vgaGeodeRec, *vgaGeodePtr;

#define newstate ((vgaGeodePtr)vgaNewVideoState)

static unsigned Geode_ExtPorts[] = { 0x22,0x23,0x80, };  /* I/O ports used by gfx_gxm_config_read */
static int Num_Geode_ExtPorts =
       (sizeof(Geode_ExtPorts)/sizeof(Geode_ExtPorts[0]));

/* ROUTINE DECLARATIONS */

static Bool	GeodeProbe();
static char *GeodeIdent();
static void	GeodeEnterLeave();
static Bool	GeodeInit();
static int GeodeValidMode();
static void *GeodeSave();
static void	GeodeRestore();
static void	GeodeAdjust();
static void	GeodeFbInit();
static Bool	GeodePitchAdjust();

/* STILL NAMED CYRIX UNTIL PROPER MAKEFILE TO CHANGE IS FOUND */

vgaVideoChipRec CYRIX = {
	GeodeProbe,
	GeodeIdent,
	GeodeEnterLeave,
	GeodeInit,
	GeodeValidMode,
	GeodeSave,
	GeodeRestore,
	GeodeAdjust,
	vgaHWSaveScreen,
	(void (*)())NoopDDA,     /* GeodeGetMode not implemented */
	GeodeFbInit,
	(void (*)())NoopDDA,     /* GeodeSetRead not implemented */
	(void (*)())NoopDDA,     /* GeodeSetWrite not implemented */
	(void (*)())NoopDDA,     /* GeodeSetReadWrite not implemented */
	0x10000,                 /* ChipMapSize */
	0x10000,                 /* ChipSegmentSize */
	16,                      /* ChipSegmentShift */
	0xFFFF,                  /* ChipSegmentMask */
	0x00000, 0x10000,        /* ChipReadBottom/Top */
	0x00000, 0x10000,        /* ChipWriteBottom/Top */
	TRUE,                    /* ChipUse2Banks */
	VGA_NO_DIVIDE_VERT,      /* ChipInterlaceType */
	{0,},                    /* ChipOptionFlags */
	8,                       /* ChipRounding */
	TRUE,                    /* ChipUseLinearAddressing */
	0x40800000,              /* ChipLinearBase */
	0x001FFFFF,              /* ChipLinearSize */
	TRUE,                    /* ChipHas16bpp */
	FALSE,                   /* ChipHas24bpp */
	FALSE,                   /* ChipHas32bpp */
	NULL,                    /* ChipBuiltinModes */
	1,                       /* ChipClockMulFactor */
	1                        /* ChipCLockDivFactor */
};

/*---------------------------------------------------------------------------
 * GeodeIdent
 *
 * The server will call this function repeatedly, until a NULL is returned, 
 * when printing out the list of configured drivers.
 *---------------------------------------------------------------------------
 */

#define NUM_CHIPSETS 3
static char chipsets[NUM_CHIPSETS][8] = {
	"GXLV", "SC1400A", "SC1200"
};

static char *GeodeIdent(n)
int n;
{
	if (n >= NUM_CHIPSETS) return(NULL);
	else return((char *)&chipsets[n][0]);
}

/*---------------------------------------------------------------------------
 * GeodeProbe
 *
 * This function detects the presence of the hardware and initializes 
 * the Durango register pointers.
 *---------------------------------------------------------------------------
 */
static Bool GeodeProbe()
{
	unsigned long cpu_version;
 
	/* SETUP IO PERMISSIONS */
	/* Works without this for FreeBSD, needed for Linux. */

    xf86ClearIOPortList(vga256InfoRec.scrnIndex);
    xf86AddIOPorts(vga256InfoRec.scrnIndex, Num_VGA_IOPorts, VGA_IOPorts);
    xf86AddIOPorts(vga256InfoRec.scrnIndex, Num_Geode_ExtPorts, Geode_ExtPorts);
	
	/* ENABLE IO PORTS */

    GeodeEnterLeave(ENTER);

	/* USE DURANGO ROUTINE TO DETECT THE CPU */

	cpu_version = gfx_detect_cpu();
	if (!cpu_version)
	{
		/* NO GEODE PROCESSOR DETECTED */

		if (xf86Verbose > 1)
		{
			ErrorF("%s %s: No Geode Processor Detected.\n",
				XCONFIG_PROBED, vga256InfoRec.name);
		}
		GeodeEnterLeave(LEAVE);
		return(FALSE);
	}

	/* DISPLAY DETECTION MESSAGE */

	ErrorF("%s %s: Geode Processor Detected (Type = %d, Version = %d.%d).\n",
	       XCONFIG_PROBED, vga256InfoRec.name, cpu_version & 0xFF, 
		   (cpu_version >> 8) & 0xFF, (cpu_version >> 16) & 0xFF);

	/* GET AMOUNT OF VIDEO MEMORY */
	/* Determine value if user has not specified it in XF86Config. */

	if (!vga256InfoRec.videoRam)
		vga256InfoRec.videoRam = gfx_get_frame_buffer_size() >> 10;

	/* FILL IN SOME INFORMATION */

	vga256InfoRec.maxClock = 135000;
	vga256InfoRec.chipset = GeodeIdent((cpu_version & 0xFF) - 1);
	vga256InfoRec.bankedMono = TRUE;
	OFLG_SET(CLOCK_OPTION_PROGRAMABLE, &vga256InfoRec.clockOptions);

	/* define option set valid for the driver */
	OFLG_SET(OPTION_SW_CURSOR, &CYRIX.ChipOptionFlags);
	OFLG_SET(OPTION_HW_CURSOR, &CYRIX.ChipOptionFlags);
	OFLG_SET(OPTION_NOACCEL, &CYRIX.ChipOptionFlags);

	/* switch on hardware cursor option */
	if( !OFLG_ISSET(OPTION_SW_CURSOR, &vga256InfoRec.options) )
	    OFLG_SET(OPTION_HW_CURSOR, &vga256InfoRec.options);

	/* HOOK ROUTINE TO ADJUST PITCH (NEED 1K OR 2K FOR ACCELERATION) */

	vgaSetPitchAdjustHook(GeodePitchAdjust);

	/* USE LINEAR ADDRESSING */

	CYRIX.ChipLinearBase = gfx_get_frame_buffer_base();
	CYRIX.ChipLinearSize = (1024 * vga256InfoRec.videoRam);
	CYRIX.ChipUseLinearAddressing = TRUE;

	/* SET DURANGO REGISTER POINTERS */
	/* The method of mapping from a physical address to a linear address */
	/* is operating system independent.  Set variables to linear address. */

	gfx_regptr = (unsigned char *)xf86MapVidMem(vga256InfoRec.scrnIndex,
		EXTENDED_REGION, (void*)gfx_get_cpu_register_base(), 0x20000);
	gfx_vidptr = (unsigned char *)xf86MapVidMem(vga256InfoRec.scrnIndex,
		EXTENDED_REGION, (void*)gfx_get_vid_register_base(), 0x1000);
	gfx_fbptr = (unsigned char *)xf86MapVidMem(vga256InfoRec.scrnIndex,
		EXTENDED_REGION, (void*)gfx_get_frame_buffer_base(), 
		gfx_get_frame_buffer_size());

	/* CHECK IF REGISTERS WERE MAPPED SUCCESSFULLY */

	if ((!gfx_regptr) || (!gfx_vidptr) || (!gfx_fbptr))
	{	
		ErrorF("%s %s: Could not map hardware registers.\n",
			XCONFIG_PROBED, vga256InfoRec.name);
		GeodeEnterLeave(LEAVE);
		return(FALSE);
	}	
	return(TRUE);
}

/*---------------------------------------------------------------------------
 * GeodeCalculatePitchBytes
 * 
 * Local routine to return pitch of the screen, in bytes.
 *---------------------------------------------------------------------------
 */
static int GeodeCalculatePitchBytes()
{
	int lineDelta = vga256InfoRec.virtualX * (vgaBitsPerPixel >> 3);
	if (!OFLG_ISSET(OPTION_NOACCEL, &vga256InfoRec.options))
	{	
		/* FORCE TO 1K OR 2K IF ACCELERATION IS ENABLED */

		if (lineDelta > 1024) lineDelta = 2048;
		else lineDelta = 1024;
	}
	else
	{
		/* FORCE TO MULTIPLE OF 16 IF NO ACCELERATION */
		
		lineDelta = (lineDelta + 15) & 0xFFF0; 
	}
	return(lineDelta);
}

/*---------------------------------------------------------------------------
 * GeodeFbInit
 * 
 * From README file: "The FbInit() function is required for drivers with
 * accelerated graphics support.  It is used to replace default cfb.banked
 * functions with accelerated chip-specific versions.
 *
 * This routine is also used to allocate graphics memory. 
 *---------------------------------------------------------------------------
 */
static void GeodeFbInit()
{
	unsigned long total_size, fb_size;

	/* ALWAYS PUT THE CURSOR AT THE END OF VIDEO MEMORY */

	total_size = gfx_get_frame_buffer_size();
	geodeCursorOffset = total_size - 512;
	fb_size = vga256InfoRec.virtualY * GeodeCalculatePitchBytes();
	geodeOffscreenOffset = fb_size;
	geodeOffscreenSize = total_size - fb_size - 512;

	/* PRINT RESULTS OF OFFSCREEN MEMORY CONFIGURATION */

	if (geodeOffscreenSize <= 0)
	{
		ErrorF("%s %s: No offscreen memory available.\n", 
			XCONFIG_PROBED, vga256InfoRec.name);
	}
	else
	{
		ErrorF("%s %s: Offscreen memory from 0x%8.8X-0x%8.8X.\n",
			XCONFIG_PROBED, vga256InfoRec.name, 
			geodeOffscreenOffset, 
			geodeOffscreenOffset+geodeOffscreenSize-1);
	}

    /* CALL "GeodeAccelInit" ROUTINE TO SET UP XAA ACCELERATED FUNCTIONS */
	/* Local routine to hook desired rendering operations to accelerate. */

	if (!OFLG_ISSET(OPTION_NOACCEL, &vga256InfoRec.options))
		GeodeAccelInit();

   	/* INSTALL HARDWARE CURSOR ROUTINES */

	if (OFLG_ISSET(OPTION_HW_CURSOR, &vga256InfoRec.options))
	{
		vgaHWCursor.Initialized = TRUE;
		vgaHWCursor.Init = GeodeCursorInit;
		vgaHWCursor.Restore = GeodeRestoreCursor;
		vgaHWCursor.Warp = GeodeWarpCursor;
		vgaHWCursor.QueryBestSize = GeodeQueryBestSize;
		ErrorF("%s %s: Using hardware cursor at offset 0x%8.8X.\n",
			XCONFIG_PROBED, vga256InfoRec.name, geodeCursorOffset);
	}
}

/*---------------------------------------------------------------------------
 * GeodePitchAdjust
 * 
 * This routine is hooked to allow the driver to enforce pitch requirements
 * that the hardware has.  For acceleartion to be used, the pitch must be
 * 1K or 2K bytes.
 *---------------------------------------------------------------------------
 */
static int GeodePitchAdjust()
{
	int pitch, lineDelta = GeodeCalculatePitchBytes();

	/* HARDWARE HAS A MAX OF 2K */

	if (lineDelta > 2048)
		FatalError("virtual display width requires a line size of more than 2048 bytes\n");

	/* CONVERT FROM BYTES TO PIXELS */

	pitch = lineDelta / (vgaBitsPerPixel >> 3);

	/* DISPLAY MESSAGE IF PITCH WAS CHANGED */

	if (pitch != vga256InfoRec.virtualX)
		ErrorF("%s %s: Display pitch set to %d pixels.\n",
		       XCONFIG_PROBED, vga256InfoRec.name, pitch);
	return pitch;
}

/*---------------------------------------------------------------------------
 * GeodeEnterLeave
 * 
 * This routine is called before and after accessing VGA registers.
 *---------------------------------------------------------------------------
 */
static void GeodeEnterLeave(enter)
Bool enter;
{
	if (enter) xf86EnableIOPorts(vga256InfoRec.scrnIndex);
	else xf86DisableIOPorts(vga256InfoRec.scrnIndex);
}

/*---------------------------------------------------------------------------
 * GeodeRestore
 * 
 * This routine restores (or sets for the first time) a display mode 
 * using the VGA registers.
 *---------------------------------------------------------------------------
 */
static void GeodeRestore(restore)
vgaGeodePtr restore;
{	unsigned char i, temp, temp2;
	unsigned long value;

	/* RESET START ADDRESS BACK TO ZERO */
	/* SoftVGA never knows it changed if panning the desktop. */

	gfx_set_display_offset(0);

	/* SIGNAL THE START OF A MODE SWITCH */

	gfx_vga_mode_switch(1);

	/* CLEAR EXTENDED VGA REGISTERS */
	/* Need to do before restoring standard VGA state so that the text */
	/* mode really gets set properly when doing the font restore. */

	gfx_vga_clear_extended();

	/* RESTORE STANDARD VGA PORTION */

	vgaHWRestore((vgaHWPtr)restore);

	/* RESTORE EXTENDED VGA PORTION */
	/* Also restore standard CRTC values since we're overwriting values. */

	gfx_vga_restore(&restore->durangovga, GFX_VGA_FLAG_MISC_OUTPUT | 
		GFX_VGA_FLAG_STD_CRTC | GFX_VGA_FLAG_EXT_CRTC);

	/* SIGNAL THE END OF A MODE SWITCH */

	gfx_vga_mode_switch(0);

	/* TELL GRAPHICS UNIT THE BITS PER PIXEL */
	/* Use the BPP from display controller that was just set by SoftVGA. */
    /* Need to do this, instead of using vgaBitsPerPixel, so that it is */
	/* properly set to 8BPP when returning to text mode from 16 BPP. */

	gfx_set_bpp(gfx_get_display_bpp());
}

/*---------------------------------------------------------------------------
 * GeodeSave
 * 
 * This routine saves the current VGA register settings.
 *---------------------------------------------------------------------------
 */
static void *GeodeSave(save)
vgaGeodePtr save;
{
	gfx_vga_struct vga;
	
	/* SAVE EXTENDED VGA REGISTERS */
	/* Also save standard CRTC and misc output since we overwrite */
	/* those values. */

	gfx_vga_save(&vga, GFX_VGA_FLAG_MISC_OUTPUT | 
		GFX_VGA_FLAG_STD_CRTC | GFX_VGA_FLAG_EXT_CRTC);

	/* SAVE STANDARD VGA PORTION */

	save = (vgaGeodePtr)vgaHWSave((vgaHWPtr)save, sizeof(vgaGeodeRec));
	save->durangovga = vga;
	return ((void *) save);
}

/*---------------------------------------------------------------------------
 * GeodeInit
 * 
 * This routine initializes the VGA structure for the specified mode. 
 * It only sets the appropriate register values in the structure.  It 
 * does not load the hardware (that is done in GeodeRestore).
 *---------------------------------------------------------------------------
 */
static Bool GeodeInit(mode)
DisplayModePtr mode;
{
	int clock = vga256InfoRec.clock[mode->Clock] / 1000;
	int hz = 60;

	/* INITIALIZE STANDARD VGA PORTION */

	if (!vgaHWInit(mode,sizeof(vgaGeodeRec)))
		return(FALSE);

	/* CALCULATE FREQUENCY */
	/* Right now Durango only supports 60 and 75 Hz modes. */

	if ((mode->CrtcHDisplay == 640) && (clock >= 30)) hz = 75;
	if ((mode->CrtcHDisplay == 800) && (clock >= 45)) hz = 75;
	if ((mode->CrtcHDisplay == 1024) && (clock >= 75)) hz = 75;
	if ((mode->CrtcHDisplay == 1280) && (clock >= 130)) hz = 75;

	/* INITIALIZE DURANGO VGA STRUCTURE FOR THE MODE */
	/* This does not set the hardware.  That is done later in "restore". */

	gfx_vga_mode(&newstate->durangovga, mode->CrtcHDisplay, 
		mode->CrtcVDisplay, vgaBitsPerPixel, hz);

	/* UPDATE THE PITCH VALUE */
	/* This is in case no acceleration is used and it is continuous. */

	gfx_vga_pitch(&newstate->durangovga, GeodeCalculatePitchBytes());
	return(TRUE);
}

/*---------------------------------------------------------------------------
 * GeodeAdjust
 * 
 * This function is called when the server needs to change the start
 * address of the frame buffer.  This is done when panning across a 
 * virtual desktop that is larger than the displayed frame buffer.
 *---------------------------------------------------------------------------
 */
static void GeodeAdjust(x, y)
int x, y;
{	
	unsigned long offset;

	/* CALCULATE BYTE OFFSET FROM (X,Y) COORDINATE */

	offset = (unsigned long) y * (unsigned long) gfx_get_display_pitch();
	offset += x;
	if (vgaBitsPerPixel > 8) offset += x;

	/* CALL DURANGO ROUTINES TO SET THE START ADDRESS */
	/* Waiting until vertical blank prevents some visual anomalies */
	/* such as "jumping" and "tearing" when panning. */

	gfx_wait_vertical_blank();
	gfx_set_display_offset(offset);
}

/*---------------------------------------------------------------------------
 * GeodeValidMode()
 * 
 * From README file: "The ValidMode() function is required.  It is used to 
 * check for any chipset dependent reasons why a graphics mode might not be
 * valid.  It gets called by higher levels of the code after the Probe()
 * stage.  In many cases no special checking will be required and this 
 * function will simply return TRUE always."
 *---------------------------------------------------------------------------
 */
static int GeodeValidMode(mode, verbose, flag)
DisplayModePtr mode;
Bool verbose;
int flag;
{
	return MODE_OK;
}

/* END OF FILE */






